{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block content %}
{% if form.errors and not form.non_field_errors %}
<p class="errornote">
{% blocktranslate count counter=form.errors.items|length %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktranslate %}
</p>
{% endif %}

{% if form.non_field_errors %}
{% for error in form.non_field_errors %}
<p class="errornote">
    {{ error }}
</p>
{% endfor %}
{% endif %}

<div id="content-main">

{% if user.is_authenticated %}
<p class="errornote">
{% blocktranslate trimmed %}
    You are authenticated as {{ username }}, but are not authorized to
    access this page. Would you like to login to a different account?
{% endblocktranslate %}
</p>
{% endif %}

<form action="{% url 'auth0_login' %}?next_url={{ request.path }}" method="post" id="login-form">{% csrf_token %}
  <div class="submit-row">
    <input type="submit" value="{% translate 'Log in with Auth0' %}">
  </div>
</form>

</div>
{% endblock %}
